strava_client library
Classes
- ActivityStats
- A set of rolled-up statistics and totals for an athlete.
- ActivityTotal
- A roll-up of metrics pertaining to a set of activities. Values are in seconds and meters.
- ActivityUrls
- ActivityZone
- Athlete
- AthleteZones
-
The authenticated athlete's heart-rate and power zones, as returned by
GET /athlete/zones. - Club
- Comment
- CreateActivityRequest
-
Model containing information to create a manual
Activityon Strava. - DetailedActivity
- DetailedAthlete
- DetailedSegment
- DetailedSegmentEffort
- DistributionBucket
- Error
- ExplorerResponse
- ExplorerSegment
- Fault
- Gear
- GeoPoint
- HeartRateZoneRanges
- HighlightedKudosers
- Lap
- MetaActivity
- MetaAthlete
- PhotosSummary
- PhotosSummaryPrimary
- PolyLineMap
- PowerZoneRanges
- RepositoryActivity
-
Repository managing all API calls related to
activities. - RepositoryAthlete
-
Repository managing all API calls related to
athletes. - RepositoryAuthentication
-
Repository managing all API calls related to
authentication. - RepositoryClub
-
Repository managing all API calls related to
clubs. - RepositoryGear
-
Repository managing all API calls related to
gear. - RepositoryRoute
-
Repository managing all API calls related to
routes. - RepositoryRunningRace
- RepositorySegment
-
Repository managing all API calls related to
segments. - RepositorySegmentEffort
-
Repository managing all API calls related to
segments effort. - RepositoryStream
-
Repository managing all API calls related to
streams. - RepositoryUpload
-
Repository managing all API calls related to
uploads. - Route
- RunningRace
- Segment
- SegmentLeaderboard
- SegmentLeaderboardEntry
- SegmentLeaderboardRequest
- SplitsMetric
- StravaClient
- A Flutter client for Strava, which supports most of Strava V3 API operations.
- StravaStream
- A single data stream for an activity, route, segment or segment effort.
- StreamCollection
- A set of StravaStreams keyed by stream type.
- SummaryActivity
- SummaryAthlete
- SummaryClub
- SummaryGear
- SummaryPRSegmentEffort
- SummarySegment
- SummarySegmentEffort
- TokenResponse
- UpdateActivityRequest
-
Model containing information to update an
Activityon Strava. - UploadActivityRequest
- UploadResponse
- Waypoint
- A custom waypoint along a Route.
- ZoneRange
-
A single zone range. A
minof 0 marks the lowest zone; amaxof -1 marks the highest. - Zones
Enums
- ActivityTypeEnum
- An enumeration of the types an activity may have.
- AuthenticationScope
- Authentication scopes allowing the user to access Strava's data.
- SegmentAgeGroup
- SegmentDateRange
- SegmentGender
- SegmentWeightClass
Extensions
Typedefs
- StreamSet = StravaStream
- Deprecated alias for StravaStream.