DetailedSegment class

Annotations
  • @JsonSerializable.new()

Constructors

DetailedSegment({int? id, int? resourceState, String? name, String? activityType, double? distance, double? averageGrade, double? maximumGrade, double? elevationHigh, double? elevationLow, List<double>? startLatlng, List<double>? endLatlng, int? climbCategory, String? city, String? state, String? country, bool? private, bool? hazardous, bool? starred, String? createdAt, String? updatedAt, double? totalElevationGain, PolyLineMap? map, int? effortCount, int? athleteCount, int? starCount, SummaryPRSegmentEffort? athleteSegmentStats, SummaryPRSegmentEffort? athletePrEffort})
DetailedSegment.fromJson(Map<String, dynamic> json)
factory

Properties

activityType String?
May take one of the following values: Ride, Run.
getter/setter pair
athleteCount int?
getter/setter pair
athletePrEffort SummaryPRSegmentEffort?
The authenticated athlete's PR effort on this segment.
getter/setter pair
athleteSegmentStats SummaryPRSegmentEffort?
getter/setter pair
averageGrade double?
getter/setter pair
city String?
getter/setter pair
climbCategory int?
The category of the climb 0, 5. Higher is harder ie. 5 is Hors catégorie, 0 is uncategorized in climb_category.
getter/setter pair
country String?
getter/setter pair
createdAt String?
getter/setter pair
distance double?
getter/setter pair
effortCount int?
getter/setter pair
elevationHigh double?
getter/setter pair
elevationLow double?
getter/setter pair
endLatlng List<double>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hazardous bool?
getter/setter pair
id int?
getter/setter pair
map PolyLineMap?
getter/setter pair
maximumGrade double?
getter/setter pair
name String?
getter/setter pair
private bool?
getter/setter pair
resourceState int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int?
getter/setter pair
starred bool?
getter/setter pair
startLatlng List<double>?
getter/setter pair
state String?
getter/setter pair
totalElevationGain double?
getter/setter pair
updatedAt String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited