SegmentLeaderboard class

Annotations
  • @JsonSerializable.new()

Constructors

SegmentLeaderboard({int? effortCount, int? entryCount, String? komType, List<SegmentLeaderboardEntry>? entries})
SegmentLeaderboard.fromJson(Map<String, dynamic> json)
factory

Properties

effortCount int?
getter/setter pair
entries List<SegmentLeaderboardEntry>?
getter/setter pair
entryCount int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
komType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited