SummaryPRSegmentEffort class
- Annotations
-
- @JsonSerializable.new()
Constructors
- SummaryPRSegmentEffort({int? prElapsedTime, String? prDate, int? effortCount, int? prActivityId})
-
SummaryPRSegmentEffort.fromJson(Map<
String, dynamic> json) -
factory
Properties
- effortCount ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- prActivityId ↔ int?
-
getter/setter pair
- prDate ↔ String?
-
getter/setter pair
- prElapsedTime ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited